@@ -5,6 +5,7 @@ from .fgcs_upload_validation import FGCSUploadValidation
 from .fgcs_generate import FGCSGenerate
 from google.cloud import storage
 
+
 class FailedValidation(Exception):
     def __init__(self, reason: str, message: str, file_name: str) -> None:
         self.reason = reason
@@ -15,9 +16,11 @@ class FailedValidation(Exception):
     def __str__(self) -> str:
         return f'{self.message} on {self.file_name}: {self.reason}'
 
+
 class FGCSUpload:
     @classmethod
-    async def encrypted_file(cls, project_id: str, bucket_name: str,  file: UploadFile, file_path: str, maximum_size: int, allowed_extension: list, file_name: str = None):
+    async def encrypted_file(cls, project_id: str, bucket_name: str, file: UploadFile, file_path: str,
+                             maximum_size: int, allowed_extension: list, file_name: str = None):
         try:
             storage_client = storage.Client(project_id)
             bucket = storage_client.bucket(bucket_name)
@@ -31,21 +34,24 @@ class FGCSUpload:
                     file.file.seek(0)
                     blob.upload_from_file(file_obj=file.file, content_type=file.content_type)
                     return {
-                                'file_name': file_name if file_name else file.filename, 
-                                'file_path': blob_path, 
-                                'file_size': await FGCSUploadValidation.convert_size(file_size), 
-                                'content_type': file.content_type,
-                                'encryption_key': key
-                            }
+                        'file_name': file_name if file_name else file.filename,
+                        'file_path': blob_path,
+                        'file_size': await FGCSUploadValidation.convert_size(file_size),
+                        'content_type': file.content_type,
+                        'encryption_key': key
+                    }
                 else:
-                    raise FailedValidation(reason='attachment size exceeds the maximum size', message='validation failed', file_name=file.filename)
+                    raise FailedValidation(reason='attachment size exceeds the maximum size',
+                                           message='validation failed', file_name=file.filename)
             else:
-                raise FailedValidation(reason='unsupported extension', message='validation failed', file_name=file.filename)
+                raise FailedValidation(reason='unsupported extension', message='validation failed',
+                                       file_name=file.filename)
         except Exception as e:
             raise e
 
     @classmethod
-    async def file(cls, project_id: str, bucket_name: str,  file: UploadFile, file_path: str, maximum_size: int, allowed_extension: list, file_name: str = None):
+    async def file(cls, project_id: str, bucket_name: str, file: UploadFile, file_path: str, maximum_size: int,
+                   allowed_extension: list, file_name: str = None, is_public: bool = False, caching_option: str = None):
         try:
             storage_client = storage.Client(project_id)
             bucket = storage_client.bucket(bucket_name)
@@ -55,22 +61,29 @@ class FGCSUpload:
                     blob_path = f'{file_path}/{file_name}' if file_name else f'{file_path}/{file.filename}'
                     blob = bucket.blob(blob_path)
                     file.file.seek(0)
+                    if caching_option is not None:
+                        blob.cache_control = caching_option
                     blob.upload_from_file(file_obj=file.file, content_type=file.content_type)
+                    if is_public:
+                        blob.make_public()
                     return {
-                                'file_name': file_name if file_name else file.filename, 
-                                'file_path': blob_path, 
-                                'file_size': await FGCSUploadValidation.convert_size(file_size), 
-                                'content_type': file.content_type
-                            }
+                        'file_name': file_name if file_name else file.filename,
+                        'file_path': blob_path,
+                        'file_size': await FGCSUploadValidation.convert_size(file_size),
+                        'content_type': file.content_type
+                    }
                 else:
-                    raise FailedValidation(reason='attachment size exceeds the maximum size', message='validation failed', file_name=file.filename)
+                    raise FailedValidation(reason='attachment size exceeds the maximum size',
+                                           message='validation failed', file_name=file.filename)
             else:
-                raise FailedValidation(reason='unsupported extension', message='validation failed', file_name=file.filename)
+                raise FailedValidation(reason='unsupported extension', message='validation failed',
+                                       file_name=file.filename)
         except Exception as e:
             raise e
 
     @classmethod
-    async def multiple_file(cls, project_id: str, bucket_name: str, file_list: list, file_path: str, maximum_size: int, allowed_extension: list, is_custom_file_name: bool = False, is_replace: bool= True):
+    async def multiple_file(cls, project_id: str, bucket_name: str, file_list: list, file_path: str, maximum_size: int,
+                            allowed_extension: list, is_custom_file_name: bool = False, is_replace: bool = True):
         try:
             storage_client = storage.Client(project_id)
             bucket = storage_client.bucket(bucket_name)
@@ -82,30 +95,35 @@ class FGCSUpload:
                 is_public = i['is_public']
                 if await FGCSUploadValidation.extensions_validation(file_object, allowed_extension):
                     if await FGCSUploadValidation.size_validation(file_size, maximum_size):
-                        blob_path = f'{file_path}/{file_name}' if is_custom_file_name else  f'{file_path}/{file_object.filename}'
+                        blob_path = f'{file_path}/{file_name}' \
+                            if is_custom_file_name else f'{file_path}/{file_object.filename}'
                         blob = bucket.blob(blob_path)
                         file_object.file.seek(0)
                         if not is_replace and blob.exists():
-                                blob = bucket.blob(f'{blob_path}_{str(uuid4())}')
+                            blob = bucket.blob(f'{blob_path}_{str(uuid4())}')
                         blob.upload_from_file(file_obj=file_object.file, content_type=file_object.content_type)
                         documents.append({
-                                    'file_name': file_name if is_custom_file_name else file_object.filename, 
-                                    'file_path': blob_path, 
-                                    'file_size': await FGCSUploadValidation.convert_size(file_size), 
-                                    'content_type': file_object.content_type
-                                })
+                            'file_name': file_name if is_custom_file_name else file_object.filename,
+                            'file_path': blob_path,
+                            'file_size': await FGCSUploadValidation.convert_size(file_size),
+                            'content_type': file_object.content_type
+                        })
                         if is_public:
                             blob.make_public()
                     else:
-                        raise FailedValidation(reason='attachment size exceeds the maximum size', message='validation failed', file_name=file_object.filename)
+                        raise FailedValidation(reason='attachment size exceeds the maximum size',
+                                               message='validation failed', file_name=file_object.filename)
                 else:
-                    raise FailedValidation(reason='unsupported extension', message='validation failed', file_name=file_object.filename)
+                    raise FailedValidation(reason='unsupported extension', message='validation failed',
+                                           file_name=file_object.filename)
             return documents
         except Exception as e:
             raise e
 
     @classmethod
-    async def multiple_encrypted_file(cls, project_id: str, bucket_name: str, file_list: list, path: str, maximum_size: int, allowed_extension: list, is_custom_file_name: bool = False, is_replace: bool= True):
+    async def multiple_encrypted_file(cls, project_id: str, bucket_name: str, file_list: list, path: str,
+                                      maximum_size: int, allowed_extension: list, is_custom_file_name: bool = False,
+                                      is_replace: bool = True):
         try:
             storage_client = storage.Client(project_id)
             bucket = storage_client.bucket(bucket_name)
@@ -116,28 +134,30 @@ class FGCSUpload:
                 file_name = i['file_name']
                 if await FGCSUploadValidation.extensions_validation(file_object, allowed_extension):
                     if await FGCSUploadValidation.size_validation(file_size, maximum_size):
-                        blob_path = f'{path}/{file_name}' if is_custom_file_name else  f'{path}/{file_object.filename}'
+                        blob_path = f'{path}/{file_name}' if is_custom_file_name else f'{path}/{file_object.filename}'
                         key = await FGCSGenerate.encryption_key()
                         b64_decode_key = base64.b64decode(key)
                         blob = bucket.blob(blob_path, encryption_key=b64_decode_key)
                         file_object.file.seek(0)
                         if not is_replace and blob.exists():
-                                blob = bucket.blob(f'{blob_path}_{str(uuid4())}', encryption_key=b64_decode_key)
+                            blob = bucket.blob(f'{blob_path}_{str(uuid4())}', encryption_key=b64_decode_key)
                         blob = bucket.blob(blob_path, encryption_key=b64_decode_key)
                         file_object.file.seek(0)
                         if not is_replace and blob.exists():
-                                blob = bucket.blob(f'{blob_path}_{str(uuid4())}')
+                            blob = bucket.blob(f'{blob_path}_{str(uuid4())}')
                         blob.upload_from_file(file_obj=file_object.file, content_type=file_object.content_type)
                         documents.append({
-                                    'file_name': file_name if is_custom_file_name else file_object.filename, 
-                                    'file_path': blob_path, 
-                                    'file_size': await FGCSUploadValidation.convert_size(file_size), 
-                                    'content_type': file_object.content_type
-                                })
+                            'file_name': file_name if is_custom_file_name else file_object.filename,
+                            'file_path': blob_path,
+                            'file_size': await FGCSUploadValidation.convert_size(file_size),
+                            'content_type': file_object.content_type
+                        })
                     else:
-                        raise FailedValidation(reason='attachment size exceeds the maximum size', message='validation failed', file_name=file_object.filename)
+                        raise FailedValidation(reason='attachment size exceeds the maximum size',
+                                               message='validation failed', file_name=file_object.filename)
                 else:
-                    raise FailedValidation(reason='unsupported extension', message='validation failed', file_name=file_object.filename)
+                    raise FailedValidation(reason='unsupported extension', message='validation failed',
+                                           file_name=file_object.filename)
             return documents
         except Exception as e:
-            raise e
\ No newline at end of file
+            raise e
